@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2020 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2023 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -13,6 +13,8 @@
 
 
 
+
+
 N.hat.posbernoulli <-
   function(eta, link, earg = list(),
            R = NULL, w = NULL,
@@ -118,7 +120,9 @@ N.hat.posbernoulli <-
                     c(sqrt(ss2 + t(dvect) %*% covun %*% dvect)) else
                     c(sqrt(ss2))
       )
-}
+}  # N.hat.posbernoulli
+
+
 
 
 
@@ -163,8 +167,7 @@ N.hat.posbernoulli <-
        y0i       = cp1 - 1,
        yr0i      = tau - cp1 - yr1i,
        yr1i      = yr1i)
-}
-
+}  # aux.posbernoulli.t
 
 
 
@@ -298,7 +301,7 @@ rposbern <-
   attr(ans, "n")          <- n
 
   ans
-}
+}  # rposbern
 
 
 
@@ -325,10 +328,7 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
   AA0 <- exp(logAA0)
   ell1 <- x * log(prob) + (1 - x) * log1p(-prob) - log1p(-AA0) / ncol(x)
   if (log.arg) ell1 else exp(ell1)
-}
-
-
-
+}  # dposbern
 
 
 
@@ -354,8 +354,8 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
 
       if (!is.numeric(y.max)) {
         eff.p <- sort(c(cutoff.prob, 1 - cutoff.prob))
-        y.max <- max(qgaitnbinom(p = eff.p[2], truncate = 0,
-                                 size, munb.p = munb)) + 10
+        y.max <- max(qgaitdnbinom(p = eff.p[2], truncate = 0,
+                                  size, munb.p = munb)) + 10
       }
 
       Y.mat <- if (intercept.only) rbind(y.min:y.max) else
@@ -369,8 +369,8 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
       trigg.term0 <- if (intercept.only) {
 
 
-        sum(c(dgaitnbinom(Y.mat2, size[1], munb.p = munb[1],
-                          truncate = 0)) *
+        sum(c(dgaitdnbinom(Y.mat2, size[1], munb.p = munb[1],
+                           truncate = 0)) *
         c(trigamma(Y.mat2 + size[1])))
       } else {
       }
@@ -389,7 +389,7 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
       as.integer(intercept.only),
       as.double(neff.row), as.double(neff.col),
       as.double(size),
-      as.double(1 - pgaitnbinom(Y.mat, size, munb.p = munb, truncate = 0
+      as.double(1 - pgaitdnbinom(Y.mat, size, munb.p = munb, truncate = 0
                             )),
       rowsums = double(neff.row))
       answerC$rowsums
@@ -405,7 +405,7 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
         ned2l.dk2 <- ned2l.dk2 - df02.dkmat2 / (1 - prob0) -
          (df0.dkmat / (1 - prob0))^2
       ned2l.dk2
-    }  # end of EIM.posNB.specialp()
+}  # end of EIM.posNB.specialp()
 
 
 
@@ -433,8 +433,8 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
 
       if (!is.numeric(y.max)) {
         eff.p <- sort(c(cutoff.prob, 1 - cutoff.prob))
-        y.max <- max(qgaitnbinom(p = eff.p[2], truncate = 0,
-                                 size, munb.p = munb)) + 10
+        y.max <- max(qgaitdnbinom(p = eff.p[2], truncate = 0,
+                                  size, munb.p = munb)) + 10
       }
 
       Y.mat <- if (intercept.only) rbind(y.min:y.max) else
@@ -442,12 +442,12 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
                       y.max-y.min+1, byrow = TRUE)
       trigg.term <- if (intercept.only) {
 
-         sum(c(dgaitnbinom(Y.mat, size[1], munb.p = munb[1],
-                           truncate = 0)) *
+         sum(c(dgaitdnbinom(Y.mat, size[1], munb.p = munb[1],
+                            truncate = 0)) *
              c(trigamma(Y.mat + size[1])))
       } else {
-         rowSums(dgaitnbinom(Y.mat, size, munb.p = munb,
-                             truncate = 0) *
+         rowSums(dgaitdnbinom(Y.mat, size, munb.p = munb,
+                              truncate = 0) *
                  trigamma(Y.mat + size))
       }
 
@@ -458,7 +458,7 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
         ned2l.dk2 <- ned2l.dk2 - df02.dkmat2 / (1 - prob0) -
          (df0.dkmat / (1 - prob0))^2
       ned2l.dk2
-    }  # end of EIM.posNB.speciald()
+}  # end of EIM.posNB.speciald()
 
 
 
@@ -466,8 +466,8 @@ dposbern <- function(x, prob, prob0 = prob, log = FALSE) {
 
 posNBD.Loglikfun2 <- function(munbval, sizeval,
                               y, x, w, extraargs) {
-  sum(c(w) * dgaitnbinom(y, sizeval, munb.p = munbval,
-                         truncate = 0, log = TRUE))
+  sum(c(w) * dgaitdnbinom(y, sizeval, munb.p = munbval,
+                          truncate = 0, log = TRUE))
 }
 
 
@@ -586,11 +586,13 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
     extra$type.fitted <- .type.fitted
     extra$colnames.y  <- colnames(y)
 
-    predictors.names <- c(namesof(param.names("munb", NOS, skip1 = TRUE),
-                                  .lmunb , earg = .emunb , tag = FALSE),
-                          namesof(param.names("size", NOS, skip1 = TRUE),
-                                  .lsize , earg = .esize , tag = FALSE))
-    predictors.names <- predictors.names[interleave.VGAM(M, M1 = M1)]
+    predictors.names <-
+      c(namesof(param.names("munb", NOS, skip1 = TRUE),
+                .lmunb , earg = .emunb , tag = FALSE),
+        namesof(param.names("size", NOS, skip1 = TRUE),
+                .lsize , earg = .esize , tag = FALSE))
+    predictors.names <- predictors.names[interleave.VGAM(M,
+                                                         M1 = M1)]
 
     gprobs.y <- .gprobs.y
     imunb <- .imunb  # Default in NULL
@@ -645,9 +647,10 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
 
       etastart <-
         cbind(
-              theta2eta(munb.init            , .lmunb , earg = .emunb ),
-              theta2eta(size.init,             .lsize , earg = .esize ))
-      etastart <- etastart[, interleave.VGAM(M, M1 = M1), drop = FALSE]
+              theta2eta(munb.init,  .lmunb , earg = .emunb ),
+              theta2eta(size.init,  .lsize , earg = .esize ))
+      etastart <- etastart[, interleave.VGAM(M, M1 = M1),
+                           drop = FALSE]
     }
   }), list( .lmunb = lmunb, .lsize = lsize,
             .imunb = imunb, .isize = isize,
@@ -659,7 +662,8 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
 
   linkinv = eval(substitute(function(eta, extra = NULL) {
     NOS <- ncol(eta) / c(M1 = 2)
-   type.fitted <- if (length(extra$type.fitted)) extra$type.fitted else {
+    type.fitted <- if (length(extra$type.fitted))
+                       extra$type.fitted else {
                      warning("cannot find 'type.fitted'. ",
                              "Returning the 'mean'.")
                      "mean"
@@ -669,11 +673,12 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
                      c("mean", "munb", "prob0"))[1]
 
     TF <- c(TRUE, FALSE)
-    munb <- eta2theta(eta[,  TF, drop = FALSE], .lmunb , earg = .emunb )
-    kmat <- eta2theta(eta[, !TF, drop = FALSE], .lsize , earg = .esize )
+    munb <- eta2theta(eta[,  TF, drop = FALSE], .lmunb , .emunb )
+    kmat <- eta2theta(eta[, !TF, drop = FALSE], .lsize , .esize )
    small.size <- 1e-10
    if (any(ind4 <- (kmat < small.size))) {
-     warning("estimates of 'size' are very small. Taking evasive action.")
+     warning("estimates of 'size' are very small. ",
+             "Taking evasive action.")
      kmat[ind4] <- small.size
    }
 
@@ -684,7 +689,7 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
     smallval <- .mds.min  # Something like this is needed
 
     if (any(big.size <- (munb / kmat < smallval))) {
-      prob0[big.size]  <- exp(-munb[big.size])  # The limit as kmat-->Inf
+      prob0[big.size]  <- exp(-munb[big.size])  # The limit
       oneminusf0[big.size] <- -expm1(-munb[big.size])
     }
 
@@ -727,14 +732,14 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
              extra = NULL,
              summation = TRUE) {
     TFvec <- c(TRUE, FALSE)
-    munb <- eta2theta(eta[,  TFvec, drop = FALSE], .lmunb , earg = .emunb )
-    kmat <- eta2theta(eta[, !TFvec, drop = FALSE], .lsize , earg = .esize )
+    munb <- eta2theta(eta[,  TFvec, drop = FALSE], .lmunb , .emunb )
+    kmat <- eta2theta(eta[, !TFvec, drop = FALSE], .lsize , .esize )
     if (residuals) {
       stop("loglikelihood residuals not implemented yet")
     } else {
       ll.elts <-
-        c(w) * dgaitnbinom(y, kmat, munb.p = munb,
-                           truncate = 0, log = TRUE)
+        c(w) * dgaitdnbinom(y, kmat, munb.p = munb,
+                            truncate = 0, log = TRUE)
       if (summation) {
         sum(ll.elts)
       } else {
@@ -744,9 +749,8 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
   }, list( .lmunb = lmunb, .lsize = lsize,
            .emunb = emunb, .esize = esize ))),
 
-  vfamily = c("posnegbinomial"),
-
-
+  vfamily = c("posnegbinomial",
+              "VGAMcategorical"),  # For "margeff"
 
 
   simslot = eval(substitute(
@@ -761,7 +765,8 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
                       .lmunb, earg = .emunb )
     kmat <- eta2theta(eta[, c(FALSE, TRUE), drop = FALSE],
                       .lsize, earg = .esize )
-    rgaitnbinom(nsim * length(munb), kmat, munb.p = munb, truncate = 0)
+    rgaitdnbinom(nsim * length(munb), kmat, munb.p = munb,
+                 truncate = 0)
   }, list( .lmunb = lmunb, .lsize = lsize,
            .emunb = emunb, .esize = esize ))),
 
@@ -779,7 +784,8 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
     okay1 <- all(is.finite(munb)) && all(0 < munb) &&
              all(is.finite(size)) && all(0 < size) &&
              all(small.size.absolute < size)
-    overdispersion <- if (okay1) all(smallval < munb / size) else FALSE
+    overdispersion <- if (okay1)
+                        all(smallval < munb / size) else FALSE
     if (!overdispersion)
       warning("parameter 'size' has very large values relative ",
               "to 'munb'; ",
@@ -796,8 +802,8 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
     NOS <- extra$NOS
 
     TFvec <- c(TRUE, FALSE)
-    munb <- eta2theta(eta[,  TFvec, drop = FALSE], .lmunb , earg = .emunb )
-    kmat <- eta2theta(eta[, !TFvec, drop = FALSE], .lsize , earg = .esize )
+    munb <- eta2theta(eta[,  TFvec, drop = FALSE], .lmunb , .emunb )
+    kmat <- eta2theta(eta[, !TFvec, drop = FALSE], .lsize , .esize )
 
 
     smallval <- .mds.min  # Something like this is needed
@@ -823,12 +829,13 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
     df0.dkmat   <- prob0 * AA16
     df02.dmunb2 <- prob0 * tempk * (1 + 1/kmat) / (1 + munb/kmat)
     df02.dkmat2 <- prob0 * ((tempm^2) / kmat + AA16^2)
-    df02.dkmat.dmunb <- -prob0 * (tempm/kmat + AA16) / (1 + munb/kmat)
+    df02.dkmat.dmunb <- -prob0 * (tempm/kmat + AA16) / (1 +
+                         munb/kmat)
 
 
 
     if (any(big.size)) {
-      prob0[big.size]  <- exp(-munb[big.size])  # The limit as kmat-->Inf
+      prob0[big.size]  <- exp(-munb[big.size])  # The limit
       oneminusf0[big.size] <- -expm1(-munb[big.size])
       df0.dmunb[big.size] <- -tempk[big.size] * prob0[big.size]
       df0.dkmat[big.size] <-  prob0[big.size] * AA16[big.size]
@@ -845,9 +852,9 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
 
     smallno <- 1e-6
     if (TRUE && any(near.boundary <- oneminusf0 < smallno)) {
-        warning("solution near the boundary; either there is no need ",
-                "to fit a positive NBD or the distribution is centred ",
-                "on the value 1")
+        warning("solution near the boundary; either there is no",
+         " need to fit a positive NBD or the distribution ",
+         "is centred on the value 1")
         oneminusf0[near.boundary] <- smallno
         prob0[near.boundary] <- 1 - oneminusf0[near.boundary]
     }
@@ -890,8 +897,8 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
     for (jay in 1:NOS) {
       eff.p <- sort(c( .cutoff.prob , 1 - .cutoff.prob ))
       Q.mins <- 1
-      Q.maxs <- qgaitnbinom(p = eff.p[2], truncate = 0,
-                            kmat[, jay], munb.p = munb[, jay]) + 10
+      Q.maxs <- qgaitdnbinom(p = eff.p[2], truncate = 0,
+                             kmat[, jay], munb.p = munb[, jay]) + 10
 
 
       eps.trig <- .eps.trig
@@ -951,7 +958,8 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
         kkvec <- kmat[ii.TF, jay]
         muvec <- munb[ii.TF, jay]
         for (ii in 1:( .nsimEIM )) {
-        ysim <- rgaitnbinom(sum(ii.TF), kkvec, munb.p = muvec, truncate = 0)
+        ysim <- rgaitdnbinom(sum(ii.TF), kkvec, munb.p = muvec,
+                             truncate = 0)
           dl.dk <- digamma(ysim + kkvec) - digamma(kkvec) -
                    (ysim - muvec) / (muvec + kkvec) +
                    log1p(-muvec / (kkvec + muvec)) +
@@ -960,7 +968,8 @@ posnegbinomial.control <- function(save.weights = TRUE, ...) {
         }  # end of for loop
 
         run.varcov <- c(run.varcov / .nsimEIM )
-        ned2l.dk2 <- if (intercept.only) mean(run.varcov) else run.varcov
+        ned2l.dk2 <- if (intercept.only)
+                       mean(run.varcov) else run.varcov
 
         wz[ii.TF, M1*jay] <- ned2l.dk2  # * (dsize.deta[ii.TF, jay])^2
       }
@@ -1178,7 +1187,7 @@ rposgeom <- function(n, prob) {
     if (residuals) {
       stop("loglikelihood residuals not implemented yet")
     } else {
-      ll.elts <- c(w) * dgaitpois(y, lambda, truncate = 0, log = TRUE)
+      ll.elts <- c(w) * dgaitdpois(y, lambda, truncate = 0, log = TRUE)
       if (summation) {
         sum(ll.elts)
       } else {
@@ -1205,7 +1214,7 @@ rposgeom <- function(n, prob) {
       warning("ignoring prior weights")
     eta <- predict(object)
     lambda <- eta2theta(eta, .link , earg = .earg )
-    rgaitpois(nsim * length(lambda), lambda, truncate = 0)
+    rgaitdpois(nsim * length(lambda), lambda, truncate = 0)
   }, list( .link = link, .earg = earg ))),
 
 
@@ -1419,11 +1428,11 @@ rposgeom <- function(n, prob) {
     if (length(extra$tau)) {
       R <- tfit$qr$qr[1:ncol.X.vlm, 1:ncol.X.vlm, drop = FALSE]
       R[lower.tri(R)] <- 0
-      tmp6 <- N.hat.posbernoulli(eta = eta, link = .link , earg = .earg ,
-                             R = R, w = w,
-                             X.vlm = X.vlm.save,
-                             Hlist = Hlist,  # 20150428; bug fixed here
-                             extra = extra, model.type = "0")
+      tmp6 <- N.hat.posbernoulli(eta = eta, link = .link ,
+                         earg = .earg , R = R, w = w,
+                         X.vlm = X.vlm.save,
+                         Hlist = Hlist,  # 20150428; bug fixed here
+                         extra = extra, model.type = "0")
       extra$N.hat    <- tmp6$N.hat
       extra$SE.N.hat <- tmp6$SE.N.hat
     }
@@ -1441,14 +1450,15 @@ rposgeom <- function(n, prob) {
       ycounts <- if ( .multiple.responses ) {
                   round(y * extra$orig.w)
                  } else {
-                   if (is.numeric(extra$orig.w)) y * w / extra$orig.w else
-                   y * w  # Convert proportions to counts
+                   if (is.numeric(extra$orig.w))
+                     y * w / extra$orig.w else
+                     y * w  # Convert proportions to counts
                  }
       nvec <- if ( .multiple.responses ) {
                 w
               } else {
-                if (is.numeric(extra$orig.w)) round(w / extra$orig.w) else
-                  round(w)
+                if (is.numeric(extra$orig.w))
+                  round(w / extra$orig.w) else round(w)
               }
       use.orig.w <- if (is.numeric(extra$orig.w)) extra$orig.w else 1
     binprob <- eta2theta(eta, .link , earg = .earg )
@@ -1457,9 +1467,9 @@ rposgeom <- function(n, prob) {
       stop("loglikelihood residuals not implemented yet")
     } else {
       answer <- c(use.orig.w) *
-        dgaitbinom(ycounts, nvec, binprob, truncate = 0, log = TRUE)
+        dgaitdbinom(ycounts, nvec, binprob, truncate = 0, log = TRUE)
       if ( .omit.constant ) {
-        answer <- answer - c(use.orig.w) * lchoose(n = nvec, k = ycounts)
+        answer <- answer - c(use.orig.w) * lchoose(nvec, ycounts)
       }
       ll.elts <- answer
       if (summation) {
@@ -1506,7 +1516,7 @@ rposgeom <- function(n, prob) {
               if (is.numeric(extra$orig.w)) round(w / extra$orig.w) else
                 round(w)
             }
-    rgaitbinom(nsim * length(eta), nvec, binprob, truncate = 0)
+    rgaitdbinom(nsim * length(eta), nvec, binprob, truncate = 0)
   }, list( .link = link, .earg = earg,
           .multiple.responses = multiple.responses,
           .omit.constant = omit.constant ))),
@@ -1558,7 +1568,6 @@ rposgeom <- function(n, prob) {
 
 
 
-
  posbernoulli.t <-
   function(link = "logitlink",
 
@@ -1701,11 +1710,11 @@ rposgeom <- function(n, prob) {
             .no.warning   = no.warning
            ))),
   linkinv = eval(substitute(function(eta, extra = NULL) {
-   type.fitted <- if (length(extra$type.fitted)) extra$type.fitted else {
-                     warning("cannot find 'type.fitted'. ",
-                             "Returning the 'probs'.")
-                     "probs"
-                   }
+    type.fitted <-
+      if (length(extra$type.fitted)) extra$type.fitted else {
+        warning("cannot find 'type.fitted'. Returning the 'probs'.")
+        "probs"
+      }
 
     type.fitted <- match.arg(type.fitted,
                      c("probs", "onempall0"))[1]
@@ -1745,7 +1754,7 @@ rposgeom <- function(n, prob) {
     tmp6 <- N.hat.posbernoulli(eta = eta, link = .link , earg = .earg ,
                                R = R, w = w,
                                X.vlm = X.vlm.save,
-                               Hlist = Hlist,  # 20150428; bug fixed here
+                               Hlist = Hlist,  # 20150428 bug fixed here
                                extra = extra, model.type = "t")
     extra$N.hat    <- tmp6$N.hat
     extra$SE.N.hat <- tmp6$SE.N.hat
@@ -1824,17 +1833,13 @@ rposgeom <- function(n, prob) {
 
     for (slocal in 1:(M-1))
       for (tlocal in (slocal+1):M)
-        wz[, iam(slocal, tlocal, M = M)] <- dprobs.deta[, slocal] *
-                                            dprobs.deta[, tlocal] *
-                                            (B.st[, slocal,tlocal] +
-                                             B.s [, slocal] *
-                                             B.s [, tlocal] / AAA) / (-AAA)
-
-
-
+        wz[, iam(slocal, tlocal, M = M)] <-
+          dprobs.deta[, slocal] * dprobs.deta[, tlocal] *
+          (B.st[, slocal, tlocal] +
+           B.s [, slocal] * B.s [, tlocal] / AAA) / (-AAA)
     wz
   }), list( .link = link, .earg = earg ))))
-}
+}  # posbernoulli.t
 
 
 
@@ -1853,8 +1858,7 @@ rposgeom <- function(n, prob) {
            I2 = FALSE,
            ipcapture = NULL,
            iprecapture = NULL,
-           p.small = 1e-4, no.warning = FALSE
-           ) {
+           p.small = 1e-4, no.warning = FALSE) {
 
 
 
@@ -2205,7 +2209,8 @@ rposgeom <- function(n, prob) {
     wz <- c(w) * wz
     wz
   }), list( .link = link, .earg = earg ))))
-}
+}  # posbernoulli.b
+
 
 
 
@@ -2657,8 +2662,7 @@ rposgeom <- function(n, prob) {
   }), list( .link = link, .earg = earg,
             .ridge.constant = ridge.constant,
             .ridge.power = ridge.power ))))
-}
-
+}  # posbernoulli.tb
 
 
 
@@ -2674,50 +2678,40 @@ setClass("posbernoulli.b",      contains = "posbernoulli.tb")
 
 
 setMethod("summaryvglmS4VGAM",  signature(VGAMff = "posbernoulli.tb"),
-  function(object,
-           VGAMff,
-           ...) {
+  function(object, VGAMff, ...) {
   object@post
 })
 
 
 
-setMethod("showsummaryvglmS4VGAM",  signature(VGAMff = "posbernoulli.tb"),
-  function(object,
-           VGAMff,
-           ...) {
+setMethod("showsummaryvglmS4VGAM", signature(VGAMff = "posbernoulli.tb"),
+  function(object, VGAMff, ...) {
  if (length(object@extra$N.hat) == 1 &&
       is.numeric(object@extra$N.hat)) {
-    cat("\nEstimate of N: ", round(object@extra$N.hat, digits = 3), "\n")
-    cat("\nStd. Error of N: ", round(object@extra$SE.N.hat, digits = 3),
-        "\n")
+   cat("\nEstimate of N: ", round(object@extra$N.hat, digits = 3), "\n")
+   cat("\nStd. Error of N: ", round(object@extra$SE.N.hat, digits = 3),
+       "\n")
 
-    confint.N <- object@extra$N.hat +
-        c(Lower = -1, Upper = 1) * qnorm(0.975) * object@extra$SE.N.hat
-    cat("\nApproximate 95 percent confidence interval for N:\n")
+   confint.N <- object@extra$N.hat +
+       c(Lower = -1, Upper = 1) * qnorm(0.975) * object@extra$SE.N.hat
+   cat("\nApproximate 95 percent confidence interval for N:\n")
   }
 })
 
 
 
-setMethod("showsummaryvglmS4VGAM",  signature(VGAMff = "posbernoulli.b"),
-  function(object,
-           VGAMff,
-           ...) {
+setMethod("showsummaryvglmS4VGAM", signature(VGAMff = "posbernoulli.b"),
+  function(object, VGAMff, ...) {
   callNextMethod(VGAMff = VGAMff, object = object, ...)
 })
 
 
 
-setMethod("showsummaryvglmS4VGAM",  signature(VGAMff = "posbernoulli.t"),
-  function(object,
-           VGAMff,
-           ...) {
+setMethod("showsummaryvglmS4VGAM", signature(VGAMff = "posbernoulli.t"),
+  function(object, VGAMff, ...) {
   callNextMethod(VGAMff = VGAMff, object = object, ...)
 })
 
 
 
 
-
-
